# Copyright (C) 2004-2024, Stefan Kanthak <stefan.kanthak@nexgo.de>

# * The software is provided "as is" without any warranty, neither express
#   nor implied.
# * In no event will the author be held liable for any damage(s) arising
#   from the use of the software.
# * Redistribution of the software is allowed only in unmodified form.
# * Permission is granted to use the software solely for personal private
#   and non-commercial purposes.
# * An individuals use of the software in his or her capacity or function
#   as an agent, (independent) contractor, employee, member or officer of
#   a business, corporation or organization (commercial or non-commercial)
#   does not qualify as personal private and non-commercial purpose.
# * Without written approval from the author the software must not be used
#   for a business, for commercial, corporate, governmental, military or
#   organizational purposes of any kind, or in a commercial, corporate,
#   governmental, military or organizational environment of any kind.

.SUFFIXES:

all: APPINIT.DLL

# https://msdn.microsoft.com/en-us/library/aa375542.aspx
# https://msdn.microsoft.com/en-us/library/dd323764.aspx

cabinet: APPINIT.CAB
	SIGNTOOL.EXE Sign /A /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /N "Stefan Kanthak" /T "http://timestamp.digicert.com/" /V APPINIT.CAB
#	SIGNTOOL.EXE Sign /AS /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /FD SHA256 /N "Stefan Kanthak" /TD SHA256 /TR "http://timestamp.digicert.com/" /V APPINIT.CAB

catalog: APPINIT.CAT
	SIGNTOOL.EXE Sign /A /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /N "Stefan Kanthak" /T "http://timestamp.digicert.com/" /V APPINIT.CAT
#	SIGNTOOL.EXE Sign /AS /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /FD SHA256 /N "Stefan Kanthak" /TD SHA256 /TR "http://timestamp.digicert.com/" /V APPINIT.CAT

clean:
	Erase APPINIT.OBJ APPINIT.DOS
	Erase APPINIT.RES APPINIT.CVT

clobber: clean
	Erase APPINIT.DLL

register: APPINIT.MAK
	REGEDIT.EXE /S <<
REGEDIT4

; (https://msdn.microsoft.com/en-us/library/dd744762.aspx)
; (https://support.microsoft.com/kb/en-us/197571)
; (https://support.microsoft.com/kb/en-us/949740)

[HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Windows]
"AppInit_DLLs"="C:\\Windows\\System32\\AppInit.Dll"
"LoadAppInit_DLLs"=dword:00000001
;"RequireSignedAppInit_DLLs"=dword:00000000
<<NOKEEP

sign: APPINIT.DLL
	SIGNTOOL.EXE Sign /A /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /N "Stefan Kanthak" /T "http://timestamp.digicert.com/" /V APPINIT.DLL
#	SIGNTOOL.EXE Sign /AS /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /FD SHA256 /N "Stefan Kanthak" /TD SHA256 /TR "http://timestamp.digicert.com/" /V APPINIT.DLL

APPINIT.DLL: APPINIT.DOS APPINIT.OBJ APPINIT.RES
	LINK.EXE /LINK /ALLOWBIND:NO /DLL /DYNAMICBASE /ENTRY:_DllMainCRTStartup /LARGEADDRESSAWARE /MERGE:.rdata=.const /MERGE:.text=.code /NOCOFFGRPINFO /NODEFAULTLIB /NOLOGO /NXCOMPAT /OPT:REF /OSVERSION:5.1 /OUT:$@ /RELEASE /STUB:APPINIT.DOS /SUBSYSTEM:WINDOWS /SWAPRUN:CD,NET /TEST /VERSION:1.0 APPINIT.OBJ APPINIT.RES KERNEL32.LIB USER32.LIB
#	LINK.EXE /LINK /ALLOWBIND:NO /DLL /DYNAMICBASE /ENTRY:_DllMainCRTStartup /INTEGRITYCHECK /LARGEADDRESSAWARE /MERGE:.rdata=.const /MERGE:.text=.code /NOCOFFGRPINFO /NODEFAULTLIB /NOLOGO /NXCOMPAT /OPT:REF /OSVERSION:5.1 /OUT:$@ /RELEASE /STUB:APPINIT.DOS /SUBSYSTEM:WINDOWS /SWAPRUN:CD,NET /TEST /VERSION:1.0 APPINIT.OBJ APPINIT.RES KERNEL32.LIB USER32.LIB

APPINIT.CVT: APPINIT.RES
	CVTRES.EXE /NOLOGO /OUT:$@ /READONLY APPINIT.RES

APPINIT.CAB: APPINIT.CAT APPINIT.INF APPINIT.MAK AMD64\APPINIT.DLL I386\APPINIT.DLL IA64\APPINIT.DLL
#	SIGNTOOL.EXE Sign /A /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /N "Stefan Kanthak" /T "http://timestamp.digicert.com/" /V APPINIT.CAT AMD64\APPINIT.DLL I386\APPINIT.DLL IA64\APPINIT.DLL
#	SIGNTOOL.EXE Sign /AS /D "Command Line Logger" /DU "https://skanthak.hier-im-netz.de/appinit.html" /FD SHA256 /N "Stefan Kanthak" /TD SHA256 /TR "http://timestamp.digicert.com/" /V APPINIT.CAT AMD64\APPINIT.DLL I386\APPINIT.DLL IA64\APPINIT.DLL
	MAKECAB.EXE /F <<
; Copyright (C) 2004-2024, Stefan Kanthak <stefan.kanthak@nexgo.de>

; https://msdn.microsoft.com/en-us/library/bb417343.aspx

.Option Explicit

.Set Cabinet=On
.Set CabinetNameTemplate=$@
.Set ChecksumWidth=8
.Set ClusterSize=4096
.Set Compress=On
.Set CompressedFileExtensionChar="_"
.Set CompressionLevel=7
.Set CompressionMemory=21
.Set CompressionType=LZX
.Set DestinationDir=
.Set DiskDirectoryTemplate=
.Set GenerateInf=On
.Set InfCabinetHeader=[SourceDisksNames]
.Set InfCabinetLineFormat=*Disk#* = *Cab#*,*CABFile*,0000-0000,
.Set InfDiskHeader=
.Set InfDiskLineFormat=
.Set InfFileHeader=[SourceDisksFiles]
.Set InfFileLineFormat=*File* = *Disk#*,,,*Size*,
.Set InfFileName=NUL:
.Set InfFooter=
.Set InfHeader=
.Set MaxCabinetSize=CDROM
.Set MaxDiskFileCount=0
.Set MaxDiskSize=CDROM
.Set MaxErrors=0
.Set ReservePerCabinetSize=0
.Set ReservePerDataBlockSize=0
.Set ReservePerFolderSize=0
.Set RptFileName=NUL:
.Set SourceDir=
.Set UniqueFiles=On

APPINIT.CAT
APPINIT.INF

AMD64\APPINIT.DLL AMD64\APPINIT.DLL

I386\APPINIT.DLL  I386\APPINIT.DLL

IA64\APPINIT.DLL  IA64\APPINIT.DLL
<<NOKEEP

APPINIT.CAT: APPINIT.INF APPINIT.MAK AMD64\APPINIT.DLL I386\APPINIT.DLL IA64\APPINIT.DLL
	MAKECAT.EXE /V <<
; Copyright (C) 2004-2024, Stefan Kanthak <stefan.kanthak@nexgo.de>

; https://msdn.microsoft.com/en-us/library/aa386967.aspx

[CatalogFiles]
<Hash>1=APPINIT.INF
<Hash>2=AMD64\APPINIT.DLL
<Hash>3=I386\APPINIT.DLL
<Hash>4=IA64\APPINIT.DLL

[CatalogHeader]
CatalogVersion=
EncodingType=
HashAlgorithms=
Name=$@
PublicVersion=
ResultDir=
<<NOKEEP

APPINIT.OBJ: APPINIT.MAK
	CL.EXE /c /Fo$@ /GA /GF /GS /Gy /Gz /nologo /O2 /Tc<< /W4 /wd4100 /we4013 /Zl
// Copyright (C) 2004-2024, Stefan Kanthak <stefan.kanthak@nexgo.de>

// https://msdn.microsoft.com/en-us/library/7f0aews7.aspx

#pragma comment(compiler)
#pragma comment(user, __TIMESTAMP__)

#define STRICT
#define UNICODE
#define WIN32_LEAN_AND_MEAN

#include <windows.h>

__declspec(safebuffers)
BOOL	CDECL	DebugFormatA([SA_FormatString(Style="printf")] LPCSTR lpFormat, ...)
{
	CHAR	szOutput[1024];
	DWORD	dwOutput;

	// https://msdn.microsoft.com/en-us/library/kb57fad8.aspx

	va_list	vaInput;
	va_start(vaInput, lpFormat);

	// https://msdn.microsoft.com/en-us/library/ms647551.aspx

	dwOutput = wvsprintfA(szOutput, lpFormat, vaInput);

	va_end(vaInput);

	if (dwOutput == 0UL)
#if 0
		return FALSE;
#else
		return DebugFormatA("APPINIT: wvsprintfA() returned error %lu\n", GetLastError());
#endif
	szOutput[dwOutput] = '\0';

	// https://msdn.microsoft.com/en-us/library/aa363362.aspx

	OutputDebugStringA(szOutput);

	return TRUE;
}

// https://msdn.microsoft.com/en-us/library/ms682583.aspx
// https://msdn.microsoft.com/en-us/library/ms682596.aspx

__declspec(safebuffers)
BOOL	WINAPI	_DllMainCRTStartup(HANDLE hModule, DWORD dwReason, CONTEXT *lpContext)
{
	// https://msdn.microsoft.com/en-us/library/ms683156.aspx

	LPCWSTR	lpCommand = GetCommandLine();

	// https://msdn.microsoft.com/en-us/library/ms647492.aspx

	DWORD	dwCommand = lstrlen(lpCommand);

	// https://msdn.microsoft.com/en-us/library/aa366569.aspx

	HANDLE	hHeap = GetProcessHeap();

	LPWSTR	lpHeap;
	WCHAR	szLogFile[MAX_PATH];
	DWORD	dwLogFile;
	HANDLE	hLogFile;

	// https://msdn.microsoft.com/en-us/library/aa383713.aspx

	LARGE_INTEGER	liLogFile;

	DWORD	dwProcessId;
	DWORD	dwThreadId;
	HWND	hWindow;
	HDESK	hDesktop;
	HWINSTA	hWinSta;
	WCHAR	szWinSta[MAX_PATH];
	DWORD	dwWinSta;
	HANDLE	hConsole;
	DWORD	dwConsole;

	// https://msdn.microsoft.com/en-us/library/ms686892.aspx

	USEROBJECTFLAGS	uof;

	// https://msdn.microsoft.com/en-us/library/ms683499.aspx

	INPUT_RECORD	irConsole;

	// https://msdn.microsoft.com/en-us/library/ms679348.aspx

	FLASHWINFO	fwi = {sizeof(fwi),
			       HWND_DESKTOP,
			       FLASHW_ALL | FLASHW_TIMER,
			       ~0U,
			       0UL};

	switch (dwReason)
	{
	case DLL_PROCESS_ATTACH:

		// called once for each process that loads this DLL

		// lpContext is NULL if this DLL is loaded dynamically;
		// lpContext holds the address of the CONTEXT of the initial
		// thread of the process if this DLL is loaded statically
		// (i.e. during process creation)

		// return TRUE to keep this DLL loaded or
		// return FALSE to fail loading this DLL

		if (hHeap == NULL)
			DebugFormatA("APPINIT: GetProcessHeap() returned error %lu\n", GetLastError());
		else
			if (dwCommand == 0UL)

				// https://msdn.microsoft.com/en-us/library/aa363362.aspx

				OutputDebugStringA("APPINIT: lstrlen() returned 0\n");
			else
			{
				dwCommand *= sizeof(L'\0');
				dwCommand += sizeof(L"\xFEFF\r\n");

				// https://msdn.microsoft.com/en-us/library/aa366597.aspx

				lpHeap = HeapAlloc(hHeap, 0UL, dwCommand);

				if (lpHeap == NULL)
					OutputDebugStringA("APPINIT: HeapAlloc() returned NULL\n");
				else
				{	// https://msdn.microsoft.com/en-us/library/dd374101.aspx

					*lpHeap = L'\xFEFF';

					// https://msdn.microsoft.com/en-us/library/ms647490.aspx

					if (lstrcpy(lpHeap + 1, lpCommand) == NULL)
						OutputDebugStringA("APPINIT: lstrcpy() returned NULL\n");
					else
						// https://msdn.microsoft.com/en-us/library/ms647487.aspx

						if (lstrcat(lpHeap, L"\r\n") == NULL)
							OutputDebugStringA("APPINIT: lstrcat() returned NULL\n");
						else
#ifdef TMP
						{	// https://msdn.microsoft.com/en-us/library/aa364992.aspx

							dwLogFile = GetTempPath(sizeof(szLogFile) / sizeof(*szLogFile), szLogFile);

							if (dwLogFile == 0UL)
								DebugFormatA("APPINIT: GetTempPath() returned error %lu\n", GetLastError());
							else
								if (dwLogFile > sizeof(szLogFile) / sizeof(*szLogFile) - sizeof("AppInit.Log"))
									OutputDebugStringA("APPINIT: length of pathname \'%TMP%\\AppInit.Log\' exceeds MAX_PATH\n");
								else
#if 0
									// https://msdn.microsoft.com/en-us/library/ms647487.aspx

									if (lstrcat(szLogFile, L"AppInit.Log") == NULL)
										OutputDebugStringA("APPINIT: lstrcat() returned NULL\n");
#else
									// https://msdn.microsoft.com/en-us/library/ms647490.aspx

									if (lstrcpy(szLogFile + dwLogFile, L"AppInit.Log") == NULL)
										OutputDebugStringA("APPINIT: lstrcpy() returned NULL\n");
#endif
#else
						{	// https://msdn.microsoft.com/en-us/library/ms724454.aspx

							dwLogFile = GetWindowsDirectory(szLogFile, sizeof(szLogFile) / sizeof(*szLogFile));

							if (dwLogFile == 0UL)
								DebugFormatA("APPINIT: GetWindowsDirectory() returned error %lu\n", GetLastError());
							else
								if (dwLogFile > sizeof(szLogFile) / sizeof(*szLogFile) - sizeof("\\Debug\\AppInit.Log"))
									OutputDebugStringA("APPINIT: length of pathname \'%SystemRoot%\\Debug\\AppInit.Log\' exceeds MAX_PATH\n");
								else
#if 0
									// https://msdn.microsoft.com/en-us/library/ms647487.aspx

									if (lstrcat(szLogFile, L"\\Debug\\AppInit.Log") == NULL)
										OutputDebugStringA("APPINIT: lstrcat() returned NULL\n");
#else
									// https://msdn.microsoft.com/en-us/library/ms647490.aspx

									if (lstrcpy(szLogFile + dwLogFile, L"\\Debug\\AppInit.Log") == NULL)
										OutputDebugStringA("APPINIT: lstrcpy() returned NULL\n");
#endif
#endif // TMP
									else
									{	// https://msdn.microsoft.com/en-us/library/aa363858.aspx

										hLogFile = CreateFile(szLogFile,
										                      FILE_APPEND_DATA,
										                      FILE_SHARE_READ | FILE_SHARE_WRITE,
										                      (LPSECURITY_ATTRIBUTES) NULL,
										                      OPEN_ALWAYS,
										                      FILE_FLAG_WRITE_THROUGH,
										                      (HANDLE) NULL);

										if (hLogFile == INVALID_HANDLE_VALUE)
											DebugFormatA("APPINIT: CreateFile() returned error %lu\n", GetLastError());
										else
										{
											lpCommand = lpHeap;
											dwCommand -= sizeof(L'\0');

											// https://msdn.microsoft.com/en-us/library/ms679360.aspx

											if (GetLastError() == ERROR_ALREADY_EXISTS)
#if 1
												// https://msdn.microsoft.com/en-us/library/aa364957.aspx

												if (!GetFileSizeEx(hLogFile, &liLogFile))
												{
													DebugFormatA("APPINIT: GetFileSizeEx() returned error %lu\n", GetLastError());

													lpCommand += 1;
													dwCommand -= sizeof(L'\xFEFF');
												}
												else
													if (liLogFile.QuadPart != 0LL)
#endif
													{
														lpCommand += 1;
														dwCommand -= sizeof(L'\xFEFF');
													}

											// https://msdn.microsoft.com/en-us/library/aa365747.aspx

											if (!WriteFile(hLogFile, lpCommand, dwCommand, &dwLogFile, (LPOVERLAPPED) NULL))
												DebugFormatA("APPINIT: WriteFile() returned error %lu\n", GetLastError());
											else
												if (dwLogFile != dwCommand)
													DebugFormatA("APPINIT: WriteFile() failed, %lu of %lu bytes written\n", dwLogFile, dwCommand);

											// https://msdn.microsoft.com/en-us/library/ms724211.aspx

											if (!CloseHandle(hLogFile))
												DebugFormatA("APPINIT: CloseHandle() returned error %lu\n", GetLastError());
										}
									}
						}
				}

				// https://msdn.microsoft.com/en-us/library/aa366701.aspx

				if (!HeapFree(hHeap, 0UL, lpHeap))
					DebugFormatA("APPINIT: HeapFree() returned error %lu\n", GetLastError());
			}

		// https://msdn.microsoft.com/en-us/library/ms682579.aspx

		if (!DisableThreadLibraryCalls(hModule))
			DebugFormatA("APPINIT: DisableThreadLibraryCalls() returned error %lu\n", GetLastError());

		return TRUE;

	case DLL_PROCESS_DETACH:

		// called once for each process that unloads this DLL

		// lpContext is NULL if this DLL is unloaded dynamically;
		// lpContext is non-NULL if this DLL is unloaded statically
		// (i.e. during process termination)

		// NOTE: the return value is ignored

		if (lpContext == NULL)
			return FALSE;

		// https://msdn.microsoft.com/en-us/library/ms683175.aspx

		hWindow = GetConsoleWindow();

		if (hWindow == NULL)
			return FALSE;

		// https://msdn.microsoft.com/en-us/library/ms633530.aspx

		if (!IsWindowVisible(hWindow))
			return FALSE;

		// https://msdn.microsoft.com/en-us/library/ms633522.aspx

		dwThreadId = GetWindowThreadProcessId(hWindow, &dwProcessId);
#if 1
		// https://msdn.microsoft.com/en-us/library/ms683180.aspx

		if (dwProcessId != GetCurrentProcessId())
#else
		// https://msdn.microsoft.com/en-us/library/ms683183.aspx

		if (dwThreadId != GetCurrentThreadId())
#endif
			return FALSE;

		fwi.hwnd = hWindow;

		// https://msdn.microsoft.com/en-us/library/ms683232.aspx

		hDesktop = GetThreadDesktop(dwThreadId);

		if (hDesktop == NULL)
			return FALSE;

		// https://msdn.microsoft.com/en-us/library/ms683225.aspx

		hWinSta = GetProcessWindowStation();

		if (hWinSta == NULL)
			return DebugFormatA("APPINIT: GetProcessWindowStation() returned error %lu\n", GetLastError());

		// https://msdn.microsoft.com/en-us/library/ms683238.aspx

		if (!GetUserObjectInformation(hWinSta, UOI_NAME, szWinSta, sizeof(szWinSta), &dwWinSta))
			return DebugFormatA("APPINIT: GetUserObjectInformation() returned error %lu\n", GetLastError());

		// https://msdn.microsoft.com/en-us/library/ms647489.aspx

		if (lstrcmpi(szWinSta, L"WinSta0") != 0)
			return FALSE;

		// https://msdn.microsoft.com/en-us/library/ms683238.aspx

		if (!GetUserObjectInformation(hWinSta, UOI_FLAGS, &uof, sizeof(uof), (LPDWORD) NULL))
			return DebugFormatA("APPINIT: GetUserObjectInformation() returned error %lu\n", GetLastError());

		if ((uof.dwFlags & WSF_VISIBLE) == 0)
			return FALSE;
#if 0
		// https://msdn.microsoft.com/en-us/library/ms683231.aspx

		hConsole = GetStdHandle(STD_ERROR_HANDLE);

		if (hConsole == INVALID_HANDLE_VALUE)
			DebugFormatA("APPINIT: GetStdHandle(STD_ERROR_HANDLE) returned error %lu\n", GetLastError());
		else
			// https://msdn.microsoft.com/en-us/library/ms687401.aspx

			if (!WriteConsole(hConsole, L"\nPress any key ...\a", 19UL, &dwConsole, NULL))
				DebugFormatA("APPINIT: WriteConsole() returned error %lu\n", GetLastError());
			else
				if (dwConsole != 19UL)
					DebugFormatA("APPINIT: WriteConsole() failed, %lu of 19 characters written\n", dwConsole);
#endif
		// https://msdn.microsoft.com/en-us/library/ms683231.aspx

		hConsole = GetStdHandle(STD_INPUT_HANDLE);

		if (hConsole == INVALID_HANDLE_VALUE)
			return DebugFormatA("APPINIT: GetStdHandle(STD_INPUT_HANDLE) returned error %lu\n", GetLastError());

		// https://msdn.microsoft.com/en-us/library/ms683147.aspx

		if (!FlushConsoleInputBuffer(hConsole))
			return DebugFormatA("APPINIT: FlushConsoleInputBuffer() returned error %lu\n", GetLastError());

		// https://msdn.microsoft.com/en-us/library/ms679347.aspx

		FlashWindowEx(&fwi);
#if 1
		// https://msdn.microsoft.com/en-us/library/ms679277.aspx

		if (!Beep(750UL, 300UL))
			DebugFormatA("APPINIT: Beep() returned error %lu\n", GetLastError());
#else
		// https://msdn.microsoft.com/en-us/library/ms680356.aspx

		if (!MessageBeep(~0U))
			DebugFormatA("APPINIT: MessageBeep() returned error %lu\n", GetLastError());
#endif
		// https://msdn.microsoft.com/en-us/library/ms684961.aspx

		while (ReadConsoleInput(hConsole, &irConsole, 1UL, &dwConsole))
			if (irConsole.EventType == KEY_EVENT)
				return FALSE;

		DebugFormatA("APPINIT: ReadConsoleInput() returned error %lu\n", GetLastError());
#if 0
		return FALSE;

	case DLL_THREAD_ATTACH:

		// called each time a thread is created in a process that has
		// already loaded (attached to) this DLL
		// not called for the thread that loads (and attaches to) this DLL
		// and threads that exist in the process before it loaded this DLL

		// NOTE: the return value is ignored

		return FALSE;

	case DLL_THREAD_DETACH:

		// same as above, but called when a thread (except the last)
		// in the process exits

		// NOTE: the return value is ignored

		return FALSE;
#endif
	default:
		return FALSE;
	}
}
<<NOKEEP

APPINIT.RES: APPINIT.MAK APPINIT.ICO
	RC.EXE /DUNICODE /Fo$@ /L 0 /N /R /V <<
// Copyright (C) 2004-2024, Stefan Kanthak <stefan.kanthak@nexgo.de>

#define STRICT

#include <winnt.h>
#include <winuser.h>
#include <winver.h>

LANGUAGE LANG_NEUTRAL, SUBLANG_NEUTRAL

1 ICON "APPINIT.ICO"

// https://msdn.microsoft.com/en-us/library/dn481241.aspx
// https://msdn.microsoft.com/en-us/library/dd371711.aspx

CREATEPROCESS_MANIFEST_RESOURCE_ID RT_MANIFEST
BEGIN
#ifdef UTF8BOM
    // https://msdn.microsoft.com/en-us/library/dd374101.aspx

    "\xEF\xBB\xBF"
#endif
    // BUG: the module loader fails with STATUS_SXS_CANT_GEN_ACTCTX
    //      when a valid encoding other than 'UTF-8' is specified!
#ifdef UTF8XML
    "<?xml version='1.0' encoding='UTF-8' standalone='yes' ?>\n"
#endif
    "<!-- Copyright (C) 2004-2024, Stefan Kanthak -->\n"
    "<assembly manifestVersion='1.0' xmlns='urn:schemas-microsoft-com:asm.v1'>\n"
    "    <assemblyIdentity name='eSKamation.Tools.AppInit DLL' processorArchitecture='*' type='win32' version='1.0.12.0' />\n"
    "    <compatibility xmlns='urn:schemas-microsoft-com:compatibility.v1'>\n"
    "        <application>\n"
    "            <supportedOS Id='{e2011457-1546-43c5-a5fe-008deee3d3f0}' />\n" // NT 6.0
    "            <supportedOS Id='{35138b9a-5d96-4fbd-8e2d-a2440225f93a}' />\n" // NT 6.1
    "            <supportedOS Id='{4a2f28e3-53b9-4441-ba9c-d69d4a4a6e38}' />\n" // NT 6.2
    "            <supportedOS Id='{1f676c76-80e1-4239-95bb-83d0f6d0da78}' />\n" // NT 6.3
    "            <supportedOS Id='{8e0f7a12-bfb3-4fe8-b9a5-48fd50a15a9a}' />\n" // NT 10
    "        </application>\n"
    "    </compatibility>\n"
    "    <description>Command Line Logger</description>\n"
    "</assembly>\n"
END

VERSION 0x20240107UL

// https://msdn.microsoft.com/en-us/library/aa381058.aspx
// https://msdn.microsoft.com/en-us/library/aa381049.aspx
// https://msdn.microsoft.com/en-us/library/aa381057.aspx

VS_VERSION_INFO VERSIONINFO
FILEFLAGS       VS_FF_PRIVATEBUILD | VS_FF_SPECIALBUILD
FILEFLAGSMASK   VS_FFI_FILEFLAGSMASK
FILEOS          VOS_NT_WINDOWS32
FILETYPE        VFT_DLL
FILESUBTYPE     VFT2_UNKNOWN
FILEVERSION     1,0,12,0
PRODUCTVERSION  1,0,12,0
BEGIN
    BLOCK "StringFileInfo"
    BEGIN
#ifdef UNICODE
        BLOCK "040004B0"
#else
        BLOCK "040004E4"
#endif
        BEGIN
            VALUE "Comments",         "https://support.microsoft.com/kb/197571\n"
                                      "https://support.microsoft.com/kb/949740\n"
                                      "https://msdn.microsoft.com/library/dd744762.aspx"
            VALUE "CompanyName",      "eSKamation\n"
                                      "https://skanthak.hier-im-netz.de/appinit.html"
            VALUE "FileDescription",  "Command Line Logger"
            VALUE "FileVersion",      "1.0.12.0"
            VALUE "InternalName",     "APPINIT"
            VALUE "LegalCopyright",   "Copyright  2004-2024, Stefan Kanthak"
        //  VALUE "LegalTrademarks",  ""
        //  VALUE "OLESelfRegister",  "Disabled"
            VALUE "OriginalFilename", "APPINIT.DLL"
            VALUE "PrivateBuild",     "NOMSVCRT"
            VALUE "ProductName",      "AppInit DLL"
            VALUE "ProductVersion",   "1.0.12.0"
            VALUE "SpecialBuild",     "Release"
        END
#ifdef UNICODE
        BLOCK "040704B0"
#else
        BLOCK "040704E4"
#endif
        BEGIN
            VALUE "Comments",         "https://support.microsoft.com/de-de/kb/197571\n"
                                      "https://support.microsoft.com/de-de/kb/949740\n"
                                      "https://msdn.microsoft.com/de-de/library/dd744762.aspx"
            VALUE "CompanyName",      "eSKamation\n"
                                      "https://skanthak.hier-im-netz.de/appinit.html"
            VALUE "FileDescription",  "Modul zum Protokollieren von Kommandozeilen"
            VALUE "FileVersion",      "1.0.12.0"
            VALUE "InternalName",     "APPINIT"
            VALUE "LegalCopyright",   "Copyright  2004-2024, Stefan Kanthak"
        //  VALUE "LegalTrademarks",  ""
        //  VALUE "OLESelfRegister",  "Disabled"
            VALUE "OriginalFilename", "APPINIT.DLL"
            VALUE "PrivateBuild",     "NOMSVCRT"
            VALUE "ProductName",      "AppInit DLL"
            VALUE "ProductVersion",   "1.0.12.0"
            VALUE "SpecialBuild",     "Release"
        END
#ifdef UNICODE
        BLOCK "040904B0"
#else
        BLOCK "040904E4"
#endif
        BEGIN
            VALUE "Comments",         "https://support.microsoft.com/en-us/kb/197571\n"
                                      "https://support.microsoft.com/en-us/kb/949740\n"
                                      "https://msdn.microsoft.com/en-us/library/dd744762.aspx"
            VALUE "CompanyName",      "eSKamation\n"
                                      "https://skanthak.hier-im-netz.de/appinit.html"
            VALUE "FileDescription",  "Command Line Logger"
            VALUE "FileVersion",      "1.0.12.0"
            VALUE "InternalName",     "APPINIT"
            VALUE "LegalCopyright",   "Copyright  2004-2024, Stefan Kanthak"
        //  VALUE "LegalTrademarks",  ""
        //  VALUE "OLESelfRegister",  "Disabled"
            VALUE "OriginalFilename", "APPINIT.DLL"
            VALUE "PrivateBuild",     "NOMSVCRT"
            VALUE "ProductName",      "AppInit DLL"
            VALUE "ProductVersion",   "1.0.12.0"
            VALUE "SpecialBuild",     "Release"
        END
    END
    BLOCK "VarFileInfo"
    BEGIN
#ifdef UNICODE
        VALUE "Translation", 0x0400, 1200, 0x0407, 1200, 0x0409, 1200
#else
        VALUE "Translation", 0x0400, 1252, 0x0407, 1252, 0x0409, 1252
#endif
    END
END
<<NOKEEP

APPINIT.OMF: APPINIT.MAK
	ML.EXE /Brepro /Fo$@ /nologo /omf /Ta<< /W3 /X
; Copyright (C) 2004-2024, Stefan Kanthak <stefan.kanthak@nexgo.de>

	.model	tiny

e_header struct				; DOS .EXE header
e_magic	word	5A4Dh			; magic number "MZ"
e_cblp	word	stop - header		; bytes on last page of file
e_cp	word	1			; pages in file
e_crlc	word	0			; number of relocation table entries
e_cparhdr word	sizeof header / 16	; size of header in paragraphs
e_minalloc word	0			; minimum extra paragraphs needed
e_maxalloc word	65535			; maximum extra paragraphs needed
e_ss	word	0			; initial (PSP relative) SS value
e_sp	word	stack - header		; initial (SS relative) SP value
e_csum	word	0			; checksum
e_ip	word	sizeof message		; initial (CS relative) IP value
e_cs	word	0			; initial (PSP relative) CS value
e_lfarlc word	sizeof header		; file address of relocation table
e_ovno	word	0			; overlay number
e_res	word	4 dup (0)		; reserved words
e_oemid	word	5719h			; OEM identifier
e_oeminfo word	2704h			; OEM information
e_res2	word	10 dup (0)		; reserved words
e_lfanew dword	0			; file address of new exe header
e_header ends

	.code

header	e_header <>

message	byte	"(C)opyright 2004-2024, Stefan Kanthak <stefan.kanthak@nexgo.de>", 0Dh, 0Ah, 07h, 24h

start:
	push	cs
	pop	ds
	xor	dx, dx
	mov	ah, 09h
	int	21h

	mov	ax, 4C01h
	int	21h
stop:
	dword	20 dup (?)
stack:
	end	start
<<NOKEEP

APPINIT.DOS: APPINIT.MAK
	CERTUTIL.EXE /DecodeHex /F /V << $@
4D 5A 90 00 01 00 00 00 04 00 00 00 FF FF 00 00   MZ..............
E0 00 00 00 43 00 00 00 40 00 00 00 00 00 00 00   ....C...@.......
00 00 00 00 19 57 04 27 00 00 00 00 00 00 00 00   .....W.'........
00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00   ................
28 43 29 6F 70 79 72 69 67 68 74 20 32 30 30 34   (C)opyright 2004
2D 32 30 32 34 2C 20 53 74 65 66 61 6E 20 4B 61   -2024, Stefan Ka
6E 74 68 61 6B 20 3C 73 74 65 66 61 6E 2E 6B 61   nthak <stefan.ka
6E 74 68 61 6B 40 6E 65 78 67 6F 2E 64 65 3E 0D   nthak@nexgo.de>.
0A 07 24 0E 1F 33 D2 B4 09 CD 21 B8 01 4C CD 21   .....3....!..L.!
<<NOKEEP

-APPINIT.ICO: APPINIT.MAK
	CERTUTIL.EXE /Decode /F /V << $@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<<NOKEEP
